summaryrefslogtreecommitdiff
path: root/scripts/prep-librewolf-dpkg.sh
diff options
context:
space:
mode:
Diffstat (limited to 'scripts/prep-librewolf-dpkg.sh')
-rwxr-xr-xscripts/prep-librewolf-dpkg.sh5
1 files changed, 4 insertions, 1 deletions
diff --git a/scripts/prep-librewolf-dpkg.sh b/scripts/prep-librewolf-dpkg.sh
index 0a7b496..dba3b95 100755
--- a/scripts/prep-librewolf-dpkg.sh
+++ b/scripts/prep-librewolf-dpkg.sh
@@ -1,7 +1,7 @@
#!/bin/sh
# File: prep-librewolf-dpkg.sh
# Location: https://gitlab.com/bgstack15/librewolf-linux.git
# Latest supported version: librewolf-125.0.1-1
# Author: bgstack15
# SPDX-License-Identifier: CC-BY-SA-4.0
# Startdate: 2020-11-29
@@ -46,6 +46,7 @@ git_source_dir=${CI_PROJECT_DIR}/git # where LibreWolf git contents are cached
debian_dir=${CI_PROJECT_DIR}/${firefox_version}/debian # where the firefox_debian.tar.xz file is extracted
source_dir=${CI_PROJECT_DIR}/${firefox_version}/librewolf_${firefox_version} # where firefox.orig.tar.xz file is extracted with --strip-components=1
work_dir=${CI_PROJECT_DIR}/prepared/
+scripts_dir="${CI_PROJECT_DIR}/scripts"
#####################################
# Download initial components
@@ -200,6 +201,8 @@ else
awk -F'/' '{print "librewolf/"$NF}' "${git_source_dir}"/source/assets/patches.txt | \
sed -r -e 's@$@ -p1@' -e '/vpn-ad/d' >> "${debian_dir}/patches/series"
#echo "librewolf/webrender_ffi.patch -p1" >> "${debian_dir}/patches/series"
+ # added 126.0 ; just defuzzing this patch
+ test -n "1" && patch -p1 "${debian_dir}/patches/librewolf/encoding_rs.patch" < "${scripts_dir}/126.0_defuzz-encoding_rs.patch"
# added 120.0.1; just defuzzing this patch
test -n "1" && patch -p1 "${debian_dir}/patches/librewolf/rust-gentoo-musl.patch" <<'EOF'
--- a/librewolf/rust-gentoo-musl.patch 2023-12-05 09:05:23.029244795 -0500
bgstack15
@@ -1,7 +1,7 @@
# File: prep-librewolf-dpkg.sh
# Location: https://gitlab.com/bgstack15/librewolf-linux.git
-# Latest supported version: librewolf-125.0.1-1
+# Latest supported version: librewolf-126.0-1
# Author: bgstack15
# SPDX-License-Identifier: CC-BY-SA-4.0